@@ -27,6 +27,11 @@ pd.set_option('display.max_rows', None, 'display.max_columns', None)
 pd.set_option('expand_frame_repr', False)
 pd.set_option('display.width', None)
 
+os.mkdir('/noted')
+os.mkdir('/noted/logs')
+os.mkdir('/noted/config')
+os.mkdir('/noted/query')
+os.mkdir('/noted/transfers')
 app_timestamp = str(time.time()).split('.')[0]
 class_transfer_broker_ = TransferBroker()
 
@@ -542,8 +547,7 @@ def main():
     logging.getLogger('numexpr.utils').setLevel(logging.WARNING) # hide logging messages from numexpr.utils module
     # Config parser
     params = configparser.ConfigParser(interpolation = configparser.ExtendedInterpolation())
-    params.read(''.join([get_python_lib(), '/params/params.ini']))
-    print('holii ', ''.join([os.path.dirname, os.path.realpath(__file__), '/params/params.ini']))
+    params.read(''.join([get_python_lib(), '/noted/params/params.ini']))
     # Argument parser
     args_parser = ArgumentParser(description = 'NOTED: a framework to optimise network traffic via the analysis of data from File Transfer Services.')
     args_parser.add_argument('config_file', help = 'the name of the configuration file [config-example.yaml]')
